==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlInputMethodListener.java <==
import java.awt.event.InputMethodListener;
import org.perl.inline.java.*;

public class      PerlInputMethodListener
       extends    InlineJavaPerlCaller
       implements InputMethodListener
{
    String sender;
    String callbacks;

    public PerlInputMethodListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void inputMethodTextChanged(java.awt.event.InputMethodEvent event) {
        try {
            CallPerl(
                "Java::Swing::InputMethodListener",
                "_InputMethodListener",
                new Object[] {sender, callbacks, "inputMethodTextChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void caretPositionChanged(java.awt.event.InputMethodEvent event) {
        try {
            CallPerl(
                "Java::Swing::InputMethodListener",
                "_InputMethodListener",
                new Object[] {sender, callbacks, "caretPositionChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlInputMethodListener.java <==
import java.awt.event.InputMethodListener;
import org.perl.inline.java.*;

public class      PerlInputMethodListener
       extends    InlineJavaPerlCaller
       implements InputMethodListener
{
    String sender;
    String callbacks;

    public PerlInputMethodListener() throws InlineJavaException { }

    public PerlInputMethodListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void inputMethodTextChanged(java.awt.event.InputMethodEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "inputMethodTextChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void caretPositionChanged(java.awt.event.InputMethodEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "caretPositionChanged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
